@@ -70,12 +70,12 @@
 #' calc_css(parameters=parms,model='3compartment')
 #' 
 #' out <- solve_pbtk(chem.name = "Bisphenol A",
-#'   days = 50, 
+#'   days = 50,                                   
 #'   daily.dose=1,
 #'   doses.per.day = 3)
 #' plot.data <- as.data.frame(out)
+#' 
 #' css <- calc_analytic_css(chem.name = "Bisphenol A")
-#' \dontrun{
 #' library("ggplot2")
 #' c.vs.t <- ggplot(plot.data,aes(time, Cplasma)) + geom_line() +
 #' geom_hline(yintercept = css) + ylab("Plasma Concentration (uM)") +
@@ -84,34 +84,6 @@
 #' ggtitle("Bisphenol A")
 #'
 #' print(c.vs.t)
-#' }
-#' 
-#' # Make a plot for all chemicals (takes a while):
-#' \dontrun{
-#' days <- NULL
-#' avg <- NULL
-#' max <- NULL
-#' for(this.cas in get_cheminfo(model="pbtk")){
-#'   css.info <- calc_css(chem.cas = this.cas, doses.per.day = 1,suppress.messages=T)
-#'   days[[this.cas]] <- css.info[["the.day"]]
-#'   avg[[this.cas]] <- css.info[["avg"]]
-#'   max[[this.cas]] <- css.info[["max"]]
-#' }
-#' days.data <- as.data.frame(days)
-#' hist <- ggplot(days.data, aes(days)) +
-#' geom_histogram(fill = "blue", binwidth = 1/6) + scale_x_log10() +
-#' ylab("Number of Chemicals") + xlab("Days") + theme(axis.text =
-#' element_text(size = 16), axis.title = element_text(size = 16))
-#' print(hist)
-#' avg.max.data <- as.data.frame(cbind(avg, max))
-#' avg.vs.max <- ggplot(avg.max.data, aes(avg, max)) + geom_point() +
-#' geom_abline() + scale_x_log10() + scale_y_log10() +
-#' xlab("Average Concentration at Steady State (uM)") +
-#' ylab("Max Concentration at Steady State (uM)") +
-#' theme(axis.text = element_text(size = 16),
-#' axis.title = element_text(size = 16))
-#' print(avg.vs.max)
-#' }
 #' 
 #' @export calc_css
 calc_css <- function(chem.name=NULL,
@@ -124,15 +96,15 @@ calc_css <- function(chem.name=NULL,
                     doses.per.day=3,
                     days = 21,
                     output.units = "uM",
-                    suppress.messages=F,
+                    suppress.messages=FALSE,
                     tissue="plasma",
                     model='pbtk',
-                    default.to.human=F,
+                    default.to.human=FALSE,
                     f.change = 0.00001,
-                    adjusted.Funbound.plasma=T,
-                    regression=T,
-                    well.stirred.correction=T,
-                    restrictive.clearance=T,
+                    adjusted.Funbound.plasma=TRUE,
+                    regression=TRUE,
+                    well.stirred.correction=TRUE,
+                    restrictive.clearance=TRUE,
                     dosing=NULL,
                     ...)
 {
@@ -200,7 +172,7 @@ calc_css <- function(chem.name=NULL,
     concentration='plasma',
     model=model,
     output.units = output.units,
-    suppress.messages=T,
+    suppress.messages=TRUE,
     adjusted.Funbound.plasma=adjusted.Funbound.plasma,
     regression=regression,
     well.stirred.correction=well.stirred.correction,
@@ -211,7 +183,7 @@ calc_css <- function(chem.name=NULL,
   out <- solve_model(parameters=parameters,
     model=model, 
     dosing=dosing,
-    suppress.messages=T,
+    suppress.messages=TRUE,
     days=days,
     output.units = output.units,
     restrictive.clearance=restrictive.clearance,
@@ -245,7 +217,7 @@ calc_css <- function(chem.name=NULL,
       initial.values = Final_Conc,  
       dosing=dosing,
       days = additional.days,
-      suppress.messages=T,
+      suppress.messages=TRUE,
       restrictive.clearance=restrictive.clearance,
       ...)
     Final_Conc <- out[dim(out)[1],state.vars]
