@@ -53,12 +53,12 @@ calc_hep_clearance <- function(chem.name=NULL,
                                dtxsid = NULL,
                                parameters=NULL,
                                species='Human',
-                               default.to.human=F,
+                               default.to.human=FALSE,
                                hepatic.model='well-stirred',
-                               suppress.messages=F,
-                               well.stirred.correction=T,
-                               restrictive.clearance=T,
-                               adjusted.Funbound.plasma=T,
+                               suppress.messages=FALSE,
+                               well.stirred.correction=TRUE,
+                               restrictive.clearance=TRUE,
+                               adjusted.Funbound.plasma=TRUE,
                                ...)
 {
   model <- hepatic.model
@@ -317,12 +317,12 @@ calc_hepatic_clearance <- function(chem.name=NULL,
                                dtxsid = NULL,
                                parameters=NULL,
                                species='Human',
-                               default.to.human=F,
+                               default.to.human=FALSE,
                                hepatic.model='well-stirred',
-                               suppress.messages=F,
-                               well.stirred.correction=T,
-                               restrictive.clearance=T,
-                               adjusted.Funbound.plasma=T,
+                               suppress.messages=FALSE,
+                               well.stirred.correction=TRUE,
+                               restrictive.clearance=TRUE,
+                               adjusted.Funbound.plasma=TRUE,
                                ...)
 {
   warning("Function \"calc_hepatic_clearance\" has been renamed to \"calc_hep_clearance\".")
