@@ -91,9 +91,22 @@
 #'
 #' @keywords Monte-Carlo dynamic simulation
 #'
+#' @return
+#' If return.all.sims == FALSE (default) a list with:
+#' \item{means}{The mean concentration for each model compartment as a function
+#' of time across the Monte Carlo simulation}
+#' \item{sds}{The standard deviation for each model compartment as a function
+#' of time across the Monte Carlo simulation}
+#'
+#' If return.all.sums == TRUE then a list is returned with:
+#' \item{stats}{The list of means and sds from return.all.sums=FALSE}
+#' \item{sims}{The concentration vs. time results for each compartment for 
+#' every (samples) set of parameters in the Monte Carlo simulation}
+#'
 #' @examples
 #' 
-#' \dontrun{
+#' \donttest{
+#' NSAMP <- 50
 #' chemname="Abamectin"
 #' times<- c(0,0.25,0.5,0.75,1,1.5,2,2.5,3,4,5)
 #' age.ranges <- seq(6,80,by=10)
@@ -122,21 +135,21 @@ calc_mc_tk<- function(chem.cas=NULL,
                         samples=1000,
                         which.quantile=0.95,
                         species="Human",
-                        suppress.messages=F,
+                        suppress.messages=FALSE,
                         model="pbtk",
-                        httkpop=T,
-                        invitrouv=T,
-                        calcrb2p=T,
+                        httkpop=TRUE,
+                        invitrouv=TRUE,
+                        calcrb2p=TRUE,
                         censored.params=list(),
                         vary.params=list(),
-                        return.samples=F,
+                        return.samples=FALSE,
                         tissue=NULL,
                         output.units="mg/L",
                         solvemodel.arg.list=list(
                           times=c(0,0.25,0.5,0.75,1,1.5,2,2.5,3,4,5)),
                         invitro.mc.arg.list=list(
-                          adjusted.Funbound.plasma=T,
-                          poormetab=T,
+                          adjusted.Funbound.plasma=TRUE,
+                          poormetab=TRUE,
                           fup.censored.dist=FALSE,
                           fup.lod=0.01,
                           fup.meas.cv=0.4,
@@ -165,10 +178,10 @@ calc_mc_tk<- function(chem.cas=NULL,
                             "Other")),
                         convert.httkpop.arg.list=list(),
                         parameterize.arg.list=list(
-                          default.to.human=F,
+                          default.to.human=FALSE,
                           clint.pvalue.threshold=0.05,
                           restrictive.clearance = T,
-                          regression=T),
+                          regression=TRUE),
                         return.all.sims=FALSE)
 {
 # We need to describe the chemical to be simulated one way or another:
@@ -210,7 +223,7 @@ calc_mc_tk<- function(chem.cas=NULL,
                         calcrb2p=calcrb2p,
                         censored.params=censored.params,
                         vary.params=vary.params,
-                        return.samples=F,
+                        return.samples=FALSE,
                         invitro.mc.arg.list=invitro.mc.arg.list,
                         httkpop.generate.arg.list=httkpop.generate.arg.list,
                         convert.httkpop.arg.list=convert.httkpop.arg.list,
@@ -223,7 +236,7 @@ calc_mc_tk<- function(chem.cas=NULL,
   for (i in 1:nrow(parameter.dt)) 
    model.out[[i]] <- do.call(model.list[[model]]$solve.func,args=c(list(
      parameters=as.list(parameter.dt[i,])),
-     suppress.messages=T,
+     suppress.messages=TRUE,
      solvemodel.arg.list))
 
   means <- set_httk_precision(Reduce("+",model.out)/length(model.out))
