@@ -57,14 +57,11 @@
 #' 
 #' calc_tkstats(chem.name='Bisphenol-A',days=100,stats='mean',model='3compartment')
 #' 
+#' \donttest{
 #' calc_tkstats(chem.name='Bisphenol-A',days=100,stats=c('peak','mean'),species='Rat')
 #' 
-#' \dontrun{
-#' # If you do not specify a chemical, calc_tkstats runs for all chemicals:
-#' all.peak.conc.stats <- calc_tkstats(days=10, doses.per.day = 3, stats = "peak")
-#' }
-#' 
 #' triclosan.stats <- calc_tkstats(days=10, chem.name = "triclosan")
+#' }
 #' 
 #' @export calc_tkstats
 calc_tkstats <-function(
@@ -83,11 +80,11 @@ calc_tkstats <-function(
                concentration='plasma',
                tissue='plasma',
                model='pbtk',
-               default.to.human=F,
-               adjusted.Funbound.plasma=T,
-               regression=T,
+               default.to.human=FALSE,
+               adjusted.Funbound.plasma=TRUE,
+               regression=TRUE,
                restrictive.clearance = T,
-               suppress.messages=F,
+               suppress.messages=FALSE,
                ...)
 {
 ### ERROR CHECKING
@@ -130,7 +127,7 @@ calc_tkstats <-function(
                 output.units=output.units,
                 model=model,
                 default.to.human=default.to.human,
-                suppress.messages=T,
+                suppress.messages=TRUE,
                 ...)
 
       if (length(stat)==1)
@@ -176,7 +173,7 @@ calc_tkstats <-function(
                       days = days,
                       species=species,
                       dosing=dosing,
-                      suppress.messages=T,
+                      suppress.messages=TRUE,
                       output.units=output.units,
                       ...)
     
@@ -223,7 +220,7 @@ calc_tkstats <-function(
         dtxsid=dtxsid,
         species=species,
         adjusted.Funbound.plasma=adjusted.Funbound.plasma,
-        suppress.messages=T)
+        suppress.messages=TRUE)
     }
   
     # Blood or plasma concentration:
@@ -322,20 +319,10 @@ calc_tkstats <-function(
 #' @return \item{AUC}{Area under the plasma concentration curve.}
 #' \item{mean.conc}{The area under the curve divided by the number of days.}
 #' \item{peak.conc}{The highest concentration.}
+#'
 #' @author Robert Pearce and John Wambaugh 
+#'
 #' @keywords Solve Statistics
-#' @examples
-#' 
-#' calc_tkstats(chem.name='Bisphenol-A',days=100,stats='mean',model='3compartment')
-#' 
-#' calc_tkstats(chem.name='Bisphenol-A',days=100,stats=c('peak','mean'),species='Rat')
-#' 
-#' \dontrun{
-#' # If you do not specify a chemical, calc_tkstats runs for all chemicals:
-#' all.peak.conc.stats <- calc_tkstats(days=10, doses.per.day = 3, stats = "peak")
-#' }
-#' 
-#' triclosan.stats <- calc_tkstats(days=10, chem.name = "triclosan")
 #' 
 #' @export calc_stats
 calc_stats <-function(
@@ -354,11 +341,11 @@ calc_stats <-function(
                concentration='plasma',
                tissue='plasma',
                model='pbtk',
-               default.to.human=F,
-               adjusted.Funbound.plasma=T,
-               regression=T,
+               default.to.human=FALSE,
+               adjusted.Funbound.plasma=TRUE,
+               regression=TRUE,
                restrictive.clearance = T,
-               suppress.messages=F,
+               suppress.messages=FALSE,
                ...)
 {
   warning("Function \"calc_stats\" has been renamed to \"calc_tkstats\".")
