@@ -62,6 +62,12 @@
 #' associated in vitro uncertainty and variability propagation function
 #' @param parameterize.arg.list Additional parameters passed to the 
 #' parameterize_* function for the model.
+#'
+#' @return
+#' A data table where each column corresponds to parameters needed for the 
+#' specified model and each row represents a different Monte Carlo sample of
+#' parameter values.
+#'
 #' @author Caroline Ring, Robert Pearce, and John Wambaugh
 #'
 #' @references 
@@ -76,7 +82,7 @@
 #' 
 #' @examples 
 #' 
-#' \dontrun{
+#' \donttest{
 #' sample_set = create_mc_samples(chem.name = 'bisphenol a')
 #' }
 #'
@@ -89,19 +95,19 @@ create_mc_samples <- function(chem.cas=NULL,
                         parameters=NULL,
                         samples=1000,
                         species="Human",
-                        suppress.messages=F,
+                        suppress.messages=FALSE,
                         model='3compartmentss',
-                        httkpop=T,
-                        invitrouv=T,
-                        calcrb2p=T,
+                        httkpop=TRUE,
+                        invitrouv=TRUE,
+                        calcrb2p=TRUE,
                         censored.params=list(),
                         vary.params=list(),
-                        return.samples=F,
+                        return.samples=FALSE,
                         tissue=NULL,
                         httkpop.dt=NULL,
                         invitro.mc.arg.list=list(
-                          adjusted.Funbound.plasma=T,
-                          poormetab=T,
+                          adjusted.Funbound.plasma=TRUE,
+                          poormetab=TRUE,
                           fup.censored.dist=FALSE,
                           fup.lod=0.01,
                           fup.meas.cv=0.4,
@@ -132,9 +138,9 @@ create_mc_samples <- function(chem.cas=NULL,
                         propagate.invitrouv.arg.list=list(),
                         parameterize.arg.list=list(
                           restrictive.clearance = T,
-                          default.to.human=F,
+                          default.to.human=FALSE,
                           clint.pvalue.threshold=0.05,
-                          regression=T))
+                          regression=TRUE))
 {
 
 #
@@ -188,7 +194,7 @@ create_mc_samples <- function(chem.cas=NULL,
                   chem.name,
                   dtxsid=dtxsid,
                   species=species,
-                  suppress.messages=T)
+                  suppress.messages=TRUE)
 # The Schmitt parameters are useful if we need to redo partitioning later:
     pschmitt <- pschmitt[!(names(pschmitt)%in%names(parameters.mean))]
     parameters.mean <- c(parameters.mean, pschmitt)
@@ -235,7 +241,7 @@ create_mc_samples <- function(chem.cas=NULL,
 #
 #
 
-  if (httkpop==T & tolower(species)=="human")
+  if (httkpop==TRUE & tolower(species)=="human")
   {
     physiology.dt <- httkpop_mc(
                        model=model,
@@ -253,7 +259,7 @@ create_mc_samples <- function(chem.cas=NULL,
                        httkpop.dt=httkpop.dt),
                        convert.httkpop.arg.list))
    } else {
-    if(httkpop==T) 
+    if(httkpop==TRUE) 
       warning('httkpop model only available for human and thus not used.\n\
 Set species=\"Human\" to run httkpop model.')   
      this.tissuedata <- subset(tissue.data, tolower(Species)==tolower(species))
@@ -335,7 +341,7 @@ Set species=\"Human\" to run httkpop model.')
              species=species,
              adjusted.Funbound.plasma=invitro.mc.arg.list$adjusted.Funbound.plasma,
              regression=parameterize.arg.list$regression,
-             suppress.messages=T)
+             suppress.messages=TRUE)
   }
 
 # If the model uses partion coefficients we need to lump each individual
@@ -385,7 +391,7 @@ Set species=\"Human\" to run httkpop model.')
 # (Rowland, 1973):      
   cl <- calc_hep_clearance(parameters=parameters.dt,
           hepatic.model='unscaled',
-          suppress.messages=T)#L/h/kg body weight
+          suppress.messages=TRUE)#L/h/kg body weight
 
   parameters.dt[,hepatic.bioavailability := calc_hep_bioavailability(
     parameters=list(
@@ -408,5 +414,5 @@ Set species=\"Human\" to run httkpop model.')
   
 #Return only the HTTK parameters for the specified model. That is, only the
 #columns whose names are in the names of the default parameter set.
-  return(parameters.dt[,model.list[[model]]$param.names,with=F])
+  return(parameters.dt[,model.list[[model]]$param.names,with=FALSE])
 }
