@@ -24,13 +24,21 @@
 #' fraction unbound (used in predict_partitioning_schmitt).
 #' @param default.to.human Substitutes missing values with human values if
 #' true.
+#' @param median.only Use median values only for fup and clint.  Default is FALSE.
+#' @param fup.ci.cutoff Cutoff for the level of uncertainty in fup estimates.
+#' This value should be between (0,1). Default is `NULL` specifying no filtering.
+#' @param clint.pvalue.threshold Hepatic clearance for chemicals where the in
+#' vitro clearance assay result has a p-values greater than the threshold are
+#' set to zero.
+#' @param suppress.messages Whether or not the output messages are suppressed.
+#' 
 #' @return \item{info}{Table/vector containing values specified in "info" for
 #' valid chemicals.}
-#' @author John Wambaugh and Robert Pearce
+#' @author John Wambaugh, Robert Pearce, and Sarah E. Davidson
 #' @keywords Retrieval
 #' @examples
 #' 
-#' \dontrun{
+#' \donttest{
 #' # List all CAS numbers for which the 3compartmentss model can be run in humans: 
 #' get_cheminfo()
 #' 
@@ -72,9 +80,13 @@ get_cheminfo <- function(info="CAS",
                          species="Human",
                          fup.lod.default=0.005,
                          model='3compartmentss',
-                         default.to.human=F)
+                         default.to.human=FALSE,
+                         median.only=FALSE,
+                         fup.ci.cutoff=TRUE,
+                         clint.pvalue.threshold=0.05,
+                         suppress.messages=FALSE)
 {
-# Parameters in this list can be retreive with the info argument:
+# Parameters in this list can be retrieve with the info argument:
   valid.info <- c("Compound",
                   "CAS",
                   "Clint",
@@ -110,7 +122,8 @@ get_cheminfo <- function(info="CAS",
   #End R CMD CHECK appeasement.
 
 # Figure out which species we support
-  valid.species <- colnames(httk::physiology.data)[!(colnames(httk::physiology.data)
+  valid.species <- 
+    colnames(httk::physiology.data)[!(colnames(httk::physiology.data)
     %in% c("Parameter","Units"))]
 # Standardize the species capitalization
   if (tolower(species) %in% tolower(valid.species)) species <-
@@ -126,6 +139,8 @@ get_cheminfo <- function(info="CAS",
   } else {
     necessary.params <- model.list[[model]]$required.params
     exclude.fup.zero <- model.list[[model]]$exclude.fup.zero
+    log.henry.threshold <- model.list[[model]]$log.henry.threshold
+    chem.class.filt     <- model.list[[model]]$chem.class.filt
   }
   if (is.null(necessary.params)) stop(paste("Necessary parameters for model",
     model,"have not been defined."))
@@ -142,66 +157,23 @@ get_cheminfo <- function(info="CAS",
     "logP"
   
   # Flag in case we can't find a column for every parameter:
-  incomplete.data <- F
-
-# Check to see if we need fup (don't we always?)
-  if (tolower("Funbound.plasma") %in% 
-    unique(tolower(c(necessary.params,info))))
-  {
-    # Identify the appropriate column for Funbound (if needed):
-    species.fup <- paste0(species,'.Funbound.plasma')
-    # Turn triples with confidence intervals into single values: 
-    temp.fup <- strsplit(as.character(chem.physical_and_invitro.data[,species.fup]),",")
-    if (any(unlist(lapply(temp.fup,length))>1)) 
-    {
-      temp.fup <-  suppressWarnings(as.numeric(unlist(lapply(temp.fup, function(x) x[[1]]))))
-    } else {
-      temp.fup <-  suppressWarnings(as.numeric(unlist(temp.fup)))
-    }    # Check to see if we will use human data where species data is missing:
-    if (default.to.human)
-    {
-      # Check to see if this is a column that already has data:
-      if (species.fup %in% colnames(chem.physical_and_invitro.data))
-      {
-        # Identify values to replace with human:
-        if (exclude.fup.zero) 
-        {
-          # Replace all the zeros if that will impact the model:
-          replace.index <- (temp.fup==0)
-          # Comparisons with NA's will produce NA's
-          replace.index[is.na(replace.index)] <- T
-        } else {
-          # Otherwise just replace NA's
-          replace.index <- is.na(chem.physical_and_invitro.data[,species.fup])
-        }
-        if (any(replace.index))
-        {
-          chem.physical_and_invitro.data[replace.index,species.fup] <-
-            chem.physical_and_invitro.data[replace.index,'Human.Funbound.plasma']
-          warning('Human values substituted for Funbound.plasma.')
-        }
-      } else {
-        chem.physical_and_invitro.data[,species.fup] <-
-          chem.physical_and_invitro.data[,'Human.Funbound.plasma']
-        warning('Human values substituted for Funbound.plasma.')
-      }
-    }
-    # Check to see if we have a column for this species in the table:
-    if (!(species.fup %in% 
-      colnames(chem.physical_and_invitro.data))) 
-    {
-      incomplete.data <- T
-    }
-    # Change the necessary parameters to the chem.physical_and_invitro.data col:
-    if (!is.null(species.fup)) 
-    {
-      necessary.params[necessary.params=="Funbound.plasma"]<-species.fup
-    }
-  }
+  incomplete.data <- FALSE
 
   # Identify the appropriate column for Clint (if needed):
   species.clint <- paste0(species,'.Clint')
   species.clint.pvalue <- paste0(species,'.Clint.pValue')
+  # Make sure capitalization matches a table column:
+  if (tolower(species.clint) %in% 
+    tolower(colnames(chem.physical_and_invitro.data)))
+  {
+    species.clint <- colnames(chem.physical_and_invitro.data)[
+      tolower(colnames(chem.physical_and_invitro.data)) ==
+      tolower(species.clint)]
+    species.clint.pvalue <- colnames(chem.physical_and_invitro.data)[
+      tolower(colnames(chem.physical_and_invitro.data)) ==
+      tolower(species.clint.pvalue)]
+  }
+  
   # Check to see if we need clint:
   if (tolower("Clint") %in% 
     unique(tolower(c(necessary.params,info))))   
@@ -220,27 +192,125 @@ get_cheminfo <- function(info="CAS",
             chem.physical_and_invitro.data[replace.index,'Human.Clint']
           chem.physical_and_invitro.data[replace.index,species.clint.pvalue] <-
             chem.physical_and_invitro.data[replace.index,'Human.Clint.pValue']
-          warning('Human values substituted for Clint and Clint.pValue.')
+          if (!suppress.messages) 
+            warning('Human values substituted for Clint and Clint.pValue.')
         }
       } else {
         chem.physical_and_invitro.data[,species.clint] <-
           chem.physical_and_invitro.data[,'Human.Clint']
         chem.physical_and_invitro.data[,species.clint.pvalue] <-
           chem.physical_and_invitro.data[,'Human.Clint.pValue']
-        warning('Human values substituted for Clint and Clint.pValue.')
+        if (!suppress.messages) 
+          warning('Human values substituted for Clint and Clint.pValue.')
       }    
     }
     # Check to see if we have a column for this species in the table:
     if (!(species.clint %in% colnames(chem.physical_and_invitro.data)))  
     {
-      incomplete.data <- T
+      incomplete.data <- TRUE
+    } else {
+      # Set observed clint values to 0 if clint.pvalue > threshold
+      if (!is.null(clint.pvalue.threshold))
+      {
+        clint.values  <- strsplit(chem.physical_and_invitro.data[,species.clint],
+          split = ",")
+        clint.pvalues <- chem.physical_and_invitro.data[,species.clint.pvalue]
+        # Replace the clint.value with 0 when clint.pvalue > threshold
+        clint.values[lapply(clint.values,length)!=4] <- 
+          ifelse(
+            clint.pvalues[lapply(clint.values,length)!=4] > 
+            clint.pvalue.threshold & 
+            !is.na(clint.pvalues[lapply(clint.values,length)!=4]),
+            yes = "0",
+            no = clint.values[lapply(clint.values,length)!=4]
+          )
+        # Replace the (median,l95,u95) with 0 when clint.pvalue > threshold
+        clint.values[lapply(clint.values,length)==4]<-
+          ifelse(
+            clint.pvalues[lapply(clint.values,length)==4] >
+            clint.pvalue.threshold & 
+            !is.na(clint.pvalues[lapply(clint.values,length)==4]),
+            yes = lapply(clint.values[lapply(clint.values,length)==4],
+            function(x){x<-c(rep("0",3),x[[4]])}),
+            no = clint.values[lapply(clint.values,length)==4]
+          )
+        
+        clint.values <- lapply(clint.values,function(x)paste(x,collapse = ","))
+        chem.physical_and_invitro.data[,species.clint] <- unlist(clint.values)
+        if (!suppress.messages & "CLINT" %in% info)
+          warning(paste(
+            'Clint values with a pvalue >',
+            clint.pvalue.threshold,
+            'were set to 0.'))
+      }    
     }
     # Change the necessary parameters to the chem.physical_and_invitro.data col:
     if (!is.null(species.clint)) 
     {
       necessary.params[necessary.params=="Clint"]<-species.clint
     }
-  } 
+  }
+
+# Check to see if we need fup (don't we always?)
+  if (tolower("Funbound.plasma") %in% 
+    unique(tolower(c(necessary.params,info))))
+  {
+    # Identify the appropriate column for Funbound (if needed):
+    species.fup <- paste0(species,'.Funbound.plasma')
+    # Turn triples with confidence intervals into single values: 
+    temp.fup <- strsplit(as.character(
+      chem.physical_and_invitro.data[,species.fup]),",")
+    if (any(unlist(lapply(temp.fup,length))>1)) 
+    {
+      temp.fup <-  suppressWarnings(as.numeric(unlist(lapply(
+        temp.fup, 
+        function(x) x[[1]]))))
+    } else {
+      temp.fup <-  suppressWarnings(as.numeric(unlist(temp.fup)))
+    }    # Check to see if we will use human data where species data is missing:
+    if (default.to.human)
+    {
+      # Check to see if this is a column that already has data:
+      if (species.fup %in% colnames(chem.physical_and_invitro.data))
+      {
+        # Identify values to replace with human:
+        if (exclude.fup.zero) 
+        {
+          # Replace all the zeros if that will impact the model:
+          replace.index <- (temp.fup==0)
+          # Comparisons with NA's will produce NA's
+          replace.index[is.na(replace.index)] <- TRUE
+        } else {
+          # Otherwise just replace NA's
+          replace.index <- is.na(chem.physical_and_invitro.data[,species.fup])
+        }
+        if (any(replace.index))
+        {
+          chem.physical_and_invitro.data[replace.index,species.fup] <-
+            chem.physical_and_invitro.data[replace.index,
+            'Human.Funbound.plasma']
+          if (!suppress.messages) 
+            warning('Human values substituted for Funbound.plasma.')
+        }
+      } else {
+        chem.physical_and_invitro.data[,species.fup] <-
+          chem.physical_and_invitro.data[,'Human.Funbound.plasma']
+        if (!suppress.messages)
+          warning('Human values substituted for Funbound.plasma.')
+      }
+    }
+    # Check to see if we have a column for this species in the table:
+    if (!(species.fup %in% 
+      colnames(chem.physical_and_invitro.data))) 
+    {
+      incomplete.data <- TRUE
+    }
+    # Change the necessary parameters to the chem.physical_and_invitro.data col:
+    if (!is.null(species.fup)) 
+    {
+      necessary.params[necessary.params=="Funbound.plasma"]<-species.fup
+    }
+  }
 
   # Check to see if we need Rblood2plasma:
   if (tolower("Rblood2plasma") %in% 
@@ -254,23 +324,26 @@ get_cheminfo <- function(info="CAS",
       if (species.rblood2plasma %in% colnames(chem.physical_and_invitro.data))
       {
         # Replace chemicals with NA's only:
-        replace.index <- is.na(chem.physical_and_invitro.data[,species.rblood2plasma])
+        replace.index <- is.na(
+          chem.physical_and_invitro.data[,species.rblood2plasma])
         if (any(replace.index))
         {
           chem.physical_and_invitro.data[replace.index,species.rblood2plasma] <-
             chem.physical_and_invitro.data[replace.index,'Human.Rblood2plasma']
-          warning('Human values substituted for Rblood2plasma.')
+          if (!suppress.messages)
+            warning('Human values substituted for Rblood2plasma.')
         }
       } else {
         chem.physical_and_invitro.data[,species.rblood2plasma] <-
           chem.physical_and_invitro.data[,'Human.Rblood2plasma']
-        warning('Human values substituted for Rblood2plasma.')
+        if (!suppress.messages)
+          warning('Human values substituted for Rblood2plasma.')
       }    
     }
     if (!(species.rblood2plasma %in% 
       colnames(chem.physical_and_invitro.data)))
     {
-      incomplete.data <- T
+      incomplete.data <- TRUE
     }
     # Change the necessary parameters to the chem.physical_and_invitro.data col:
     if (!is.null(species.rblood2plasma)) 
@@ -287,8 +360,10 @@ get_cheminfo <- function(info="CAS",
   
   # Pare the chemical data down to only those chemicals where all the necessary
   # parameters are not NA
-    good.chemicals.index <- apply(chem.physical_and_invitro.data[,necessary.params],
-      1,function(x) all(!is.na(x)))
+    good.chemicals.index <- apply(
+      chem.physical_and_invitro.data[,necessary.params],
+      1,
+      function(x) all(!is.na(x)))
       
   # If we need fup:
     if (tolower(paste(species,"Funbound.plasma",sep=".")) %in% 
@@ -308,9 +383,29 @@ get_cheminfo <- function(info="CAS",
   # If we are exclude the fups with a zero, then get rid of those:
       if (exclude.fup.zero) 
       {
-        suppressWarnings(fup.values.numeric[fup.values==0] <- F)
+        suppressWarnings(fup.values.numeric[fup.values==0] <- FALSE)
       }
       good.chemicals.index <- good.chemicals.index & fup.values.numeric
+      
+      # If we are excluding fups with uncertain ci intervals, then get rid of those:
+      if(fup.ci.cutoff){
+        # separate concatenated values
+        fup.ci.diff <- strsplit(as.character(
+          chem.physical_and_invitro.data[,species.fup]),",")
+        # if only one element assume TRUE
+        fup.ci.diff[lapply(fup.ci.diff,length)!=3] <- TRUE
+        # if 3 elements, then calculate interval length and check if it passes the cutoff 
+        fup.ci.diff[lapply(fup.ci.diff,length)==3] <- 
+          lapply(fup.ci.diff[lapply(fup.ci.diff,length)==3],function(x){
+            t.ci <- as.numeric(x)
+            # Fup's where confidence interval spans nearly all possible values:
+            out  <- ifelse((t.ci[3]>0.9 & t.ci[2]<0.1),yes = FALSE, no = TRUE)
+            return(out)
+          })
+        fup.ci.cert <- unlist(fup.ci.diff)
+        
+        good.chemicals.index <- good.chemicals.index & fup.ci.cert
+      }
     }
     
 # If we need Clint:
@@ -319,14 +414,40 @@ get_cheminfo <- function(info="CAS",
     {
       clint.values <- chem.physical_and_invitro.data[,species.clint]
       clint.values.numeric <- suppressWarnings(!is.na(as.numeric(clint.values)))
-      clint.values.dist <- suppressWarnings(nchar(clint.values) - nchar(gsub(",","",clint.values))==3)
-      clint.values.dist[is.na(clint.values.dist)] <- F
+      clint.values.dist <- 
+        suppressWarnings(nchar(clint.values) - 
+        nchar(gsub(",","",clint.values))==3)
+      clint.values.dist[is.na(clint.values.dist)] <- FALSE
       good.chemicals.index <- good.chemicals.index &
 # Either a numeric value:
         (clint.values.numeric |
 # or four values separated by three commas:
         clint.values.dist)
     }
+    
+    # If we need to remove volatile compounds:
+    if(!is.null(log.henry.threshold)){
+      # keep compounds with logHenry constant less than threshold & 'NA'
+      log.henry.pass <- 
+        chem.physical_and_invitro.data[,"logHenry"] < 
+        log.henry.threshold|is.na(chem.physical_and_invitro.data[,"logHenry"])
+      # obtain the the chemical indexes to keep
+      good.chemicals.index <- good.chemicals.index & log.henry.pass
+    }
+    # If we need to remove compounds belonging to a given chemical class:
+    if(!is.null(chem.class.filt)){
+      # obtain the chemical classifications
+      chem.class <- strsplit(
+        chem.physical_and_invitro.data[,"Chemical.Class"],
+        split = ",")
+      # check if the chemical class is in the filter-out object
+      no.chem.class.index <- lapply(
+        chem.class,
+        function(x)!(any(x%in%chem.class.filt)))
+      # obtain the chemical indexes to keep
+      good.chemicals.index <- good.chemicals.index & unlist(no.chem.class.index)
+    }
+    
 # Kep just the chemicals we want:    
     good.chemical.data <- chem.physical_and_invitro.data[good.chemicals.index,] 
     
@@ -365,10 +486,23 @@ get_cheminfo <- function(info="CAS",
     
     if (!exclude.fup.zero) 
     {
-      fup.zero.chems <- suppressWarnings(as.numeric(this.subset[,species.fup]) == 0)
+      fup.zero.chems <- 
+        suppressWarnings(as.numeric(this.subset[,species.fup]) == 0)
       fup.zero.chems[is.na(fup.zero.chems)] <- FALSE
       this.subset[fup.zero.chems, species.fup] <- fup.lod.default
     }
+    # If we want the median values only for fup and clint
+    if(median.only){
+      fup.values      <- strsplit(as.character(this.subset[,species.fup]),",")
+      fup.median.only <- lapply(fup.values, function(x) x[[1]])
+      this.subset[,species.fup] <- as.numeric(unlist(fup.median.only))
+      
+      clint.values      <- strsplit(
+        as.character(this.subset[,species.clint]),
+        ",")
+      clint.median.only <- lapply(clint.values,function(x)x[[1]])
+      this.subset[,species.clint] <- as.numeric(unlist(clint.median.only))
+    }
                                 
     return.info <- this.subset[,colnames(this.subset)%in%info]
   } else return.info <- NULL 
