@@ -107,18 +107,18 @@ solve_3comp <- function(chem.name = NULL,
                     dose = NULL,
                     doses.per.day=NULL,
                     initial.values=NULL,
-                    plots=F,
-                    suppress.messages=F,
+                    plots=FALSE,
+                    suppress.messages=FALSE,
                     species="Human",
-                    iv.dose=F,
+                    iv.dose=FALSE,
                     output.units='uM',
                     method="lsoda",rtol=1e-8,atol=1e-12,
-                    default.to.human=F,
-                    recalc.blood2plasma=F,
-                    recalc.clearance=F,
+                    default.to.human=FALSE,
+                    recalc.blood2plasma=FALSE,
+                    recalc.clearance=FALSE,
                     dosing.matrix=NULL,
-                    adjusted.Funbound.plasma=T,
-                    regression=T,
+                    adjusted.Funbound.plasma=TRUE,
+                    regression=TRUE,
                     restrictive.clearance = T,
                     minimum.Funbound.plasma=0.0001,
                     monitor.vars=NULL,
