@@ -144,6 +144,7 @@
 #' 
 #' solve_gas_pbtk(chem.name='Pyrene',dose=.5,days = 3,tsteps=2)
 #' 
+#' \donttest{
 #' out <- solve_gas_pbtk(chem.name='pyrene',exp.conc = 0, doses.per.day = 2,
 #' daily.dose = 3, plots=TRUE,initial.values=c(Aven=20))
 #' 
@@ -152,6 +153,7 @@
 #'                   
 #' params <- parameterize_gas_pbtk(chem.cas="80-05-7")
 #' solve_gas_pbtk(parameters=params)
+#' }
 #' 
 #' @export solve_gas_pbtk
 #' @useDynLib httk
@@ -174,16 +176,16 @@ solve_gas_pbtk <- function(chem.name = NULL,
                            exp.duration = 12,
                            fcontrol = list(method='constant',rule=2,f=0), 
                            initial.values=NULL,
-                           plots=F,
-                           suppress.messages=F,
+                           plots=FALSE,
+                           suppress.messages=FALSE,
                            species="Human",
                            output.units='uM',
                            method="lsoda",rtol=1e-8,atol=1e-12,
-                           default.to.human=F,
-                           recalc.blood2plasma=F,
-                           recalc.clearance=F,
-                           adjusted.Funbound.plasma=T,
-                           regression=T,
+                           default.to.human=FALSE,
+                           recalc.blood2plasma=FALSE,
+                           recalc.clearance=FALSE,
+                           adjusted.Funbound.plasma=TRUE,
+                           regression=TRUE,
                            restrictive.clearance = T,
                            minimum.Funbound.plasma=0.0001,
                            monitor.vars=NULL,
